diff --git a/Doc/Manual/Warnings.html b/Doc/Manual/Warnings.html
index 26515bedf..f6f1a9d28 100644
--- a/Doc/Manual/Warnings.html
+++ b/Doc/Manual/Warnings.html
@@ -498,7 +498,8 @@ example.i(4): Syntax error in input.
-- 870. Warning for classname: Base baseclass ignored. Multiple inheritance is not supported in Php4. (Php4).
+
- 870. Warning for classname: Base baseclass ignored. Multiple inheritance is not supported in Php4. (Php).
+
- 871. Unrecognized pragma pragma. (Php).
14.8.7 User defined (900-999)
diff --git a/Source/Modules/php4.cxx b/Source/Modules/php4.cxx
index 02532d035..e98d74f43 100644
--- a/Source/Modules/php4.cxx
+++ b/Source/Modules/php4.cxx
@@ -44,8 +44,8 @@
*/
/*
* TODO: Replace remaining stderr messages with Swig_warning (need to add more
* WARN_XXX codes to be able to...)
*/
char cvsroot_php4_cxx[] = "$Header$";
@@ -1928,7 +1928,6 @@ public:
String *value = Getattr(n,"value");
if (Strcmp(lang,"php4") == 0) {
-
if (Strcmp(type, "code") == 0) {
if (value) {
Printf(pragma_code, "%s\n", value);
@@ -1942,8 +1941,8 @@ public:
Printf(pragma_phpinfo, "%s\n", value);
}
} else {
- Printf(stderr, "%s : Line %d. Unrecognized pragma.\n",
- input_file, line_number);
+ Swig_warning(WARN_PHP4_UNKNOWN_PRAGMA, input_file, line_number,
+ "Unrecognized pragma <%s>.\n", type);
}
}
}
@@ -44,8 +44,8 @@
*/
/*
- * TODO: Replace remaining stderr messages with Swig_warning (need to add more
- * WARN_XXX codes to be able to...)
+ * TODO: Replace remaining stderr messages with Swig_error or Swig_warning
+ * (may need to add more WARN_PHP4_xxx codes...)
*/
char cvsroot_php4_cxx[] = "$Header$";